@@ -86,9 +86,9 @@ def git_regex_search(url, pattern):
         try:
             # repo = g.get_repo(args.repo)
             # results = repo.search_code(pattern)
-            results = search_repo(args.repo, pattern)
+            results = search_repo(url, pattern)
             for result in results:
-                print(colored(f"{args.repo}/tree/master/{result[0].path}#L{result[1]}", "green"))
+                print(colored(f"{url}/tree/master/{result[0].path}#L{result[1]}", "green"))
         except Exception as e:
             print(f"Error: {e}")
 
